@@ -35,9 +35,7 @@ class Step:
         self.pause_message = None if "manual_pause_message" not in parameters else parameters["manual_pause_message"]
 
     def add_command_block(self, block):
-        for command in block.split('\n'):
-            if len(command.strip()):
-                self.commands.append(Command(command.strip()))
+        self.commands.append(Command(block.strip()))
 
     def run_all_commands(self, manual, shell):
         if manual and self.pause_message is not None:
