@@ -8,7 +8,7 @@ import os
 import subprocess
 import unittest
 
-from mechanical_markdown import MechanicalMarkdown
+from mechanical_markdown import MechanicalMarkdown, MarkdownAnnotationError
 from unittest.mock import patch, MagicMock, call
 
 
@@ -200,6 +200,9 @@ name: basic test
 
 ```bash
 echo "test"
+```
+
+```bash
 echo "test2"
 ```
 
@@ -254,30 +257,16 @@ expected_stderr_lines:
 ```bash
 echo "test"
 echo "test2"
-echo "error" >2
+echo "error" 1>&2
 ```
 
 <!-- END_STEP -->
 """
-        self.prep_command_ouput("test", "", 0)
-        self.prep_command_ouput("test2", "", 0)
-        self.prep_command_ouput("", "error", 0)
+        self.prep_command_ouput("test\ntest2", "error", 0)
         mm = MechanicalMarkdown(test_data)
         success, report = mm.exectute_steps(False)
         self.assertTrue(success)
-        calls = [call(['bash', '-c', 'echo "test"'],
-                      stdout=subprocess.PIPE,
-                      stderr=subprocess.PIPE,
-                      universal_newlines=True,
-                      env=os.environ),
-                 call().communicate(timeout=60),
-                 call(['bash', '-c', 'echo "test2"'],
-                      stdout=subprocess.PIPE,
-                      stderr=subprocess.PIPE,
-                      universal_newlines=True,
-                      env=os.environ),
-                 call().communicate(timeout=60),
-                 call(['bash', '-c', 'echo "error" >2'],
+        calls = [call(['bash', '-c', 'echo "test"\necho "test2"\necho "error" 1>&2'],
                       stdout=subprocess.PIPE,
                       stderr=subprocess.PIPE,
                       universal_newlines=True,
@@ -349,8 +338,8 @@ echo "bar" >2
 
         expected_output = """Step: basic test
 \tcommands to run with 'bash -c':
-\t\t`echo "test"`
-\t\t`echo "test2"`
+\t\t`echo "test"
+echo "test2"`
 \tExpected stdout:
 \t\ttest
 \t\ttest2
@@ -358,8 +347,8 @@ echo "bar" >2
 
 Step: step 2
 \tcommands to run with 'bash -c':
-\t\t`echo "foo"`
-\t\t`echo "bar" >2`
+\t\t`echo "foo"
+echo "bar" >2`
 \tExpected stdout:
 \t\tfoo
 \tExpected stderr:
@@ -448,3 +437,34 @@ echo "test"
                                            stderr=subprocess.PIPE,
                                            universal_newlines=True,
                                            env=os.environ)
+
+    def test_missing_end_tag_throws_exception(self):
+        test_data = """
+<!-- STEP
+name: basic test
+-->
+
+```bash
+echo "test"
+```
+
+"""
+        with self.assertRaises(MarkdownAnnotationError):
+            MechanicalMarkdown(test_data)
+
+    def test_missing_extra_tag_throws_exception(self):
+        test_data = """
+<!-- STEP
+name: basic test
+-->
+
+```bash
+echo "test"
+```
+
+<!-- END_STEP -->
+
+<!-- END_STEP -->
+"""
+        with self.assertRaises(MarkdownAnnotationError):
+            MechanicalMarkdown(test_data)
